Function resolve_sessions_root
Source pub fn resolve_sessions_root(sessions_root: Option<PathBuf>) -> Result<PathBuf>
Resolve the codex-ws state root from an optional CLI override.
Arguments
sessions_root - Optional user-provided state root.
Returns
The explicit path with home expansion, or the default codex-ws state root.
Errors
Returns an error when the default state root cannot be resolved.