pub struct RunArgs {
pub provider: String,
pub workspace: PathBuf,
pub config_db: PathBuf,
pub sessions_root: PathBuf,
pub image: Option<String>,
}Expand description
Arguments used to launch a workspace sandbox.
Fields
provider: StringProvider configuration name to load from the local configuration database.
workspace: PathBufWorkspace name or path to a workspace manifest YAML file.
config_db: PathBufPath to the local provider configuration database.
sessions_root: PathBufHost directory used to store per-workspace Codex sessions.
image: Option<String>Docker image containing the Codex CLI.