pub enum ConfigError {
MissingHomeDirectory,
UnsupportedConfigName {
name: String,
supported: &'static str,
},
Io(Error),
Json(Error),
InvalidSystemClock,
}Expand description
Errors returned while reading or writing user configuration.
Variants
MissingHomeDirectory
The operating system did not expose a usable home directory.
UnsupportedConfigName
The requested configuration key is not supported.
Fields
Io(Error)
The configuration file could not be read or written.
Json(Error)
The configuration file contained invalid JSON.
InvalidSystemClock
The system clock cannot be used to create a unique temporary file name.