Function load_user_config
Source pub fn load_user_config(path: &Path) -> Result<UserConfig, ConfigError>
Load user configuration from a file path.
Arguments
path - Configuration JSON path.
Returns
Parsed user configuration, or an empty configuration when the file does not exist.
Errors
Returns an error when the file cannot be read or its JSON is invalid.