pub enum ManifestError {
Read {
path: PathBuf,
source: Error,
},
Yaml(Error),
EmptyName,
NoFolders,
EmptyRuntimeImage,
RuntimeSpec(RuntimeSpecError),
FolderMissing {
path: PathBuf,
},
FolderNotDirectory {
path: PathBuf,
},
}Expand description
Errors returned while loading or validating workspace manifests.
Variants
Read
The manifest file could not be read.
Yaml(Error)
The manifest YAML could not be parsed.
EmptyName
The workspace name was empty or only whitespace.
NoFolders
The workspace did not include any folders.
EmptyRuntimeImage
The workspace runtime image was empty or only whitespace.
RuntimeSpec(RuntimeSpecError)
The workspace runtime language selection was invalid.
FolderMissing
A workspace folder path does not exist.
FolderNotDirectory
A workspace folder path exists but is not a directory.