Module provider

Module provider 

Provider configuration loading from the local configuration database.

Structs

CodexProvider
Codex provider configuration loaded from the local configuration database.

Enums

ProviderError
Errors returned while loading Codex provider configuration.

Functions

load_codex_providers
Load all Codex providers from a local configuration database.
load_codex_providers_from_connection
Load all Codex providers from an existing SQLite connection.