Module runtime

Module runtime 

Workspace runtime setup validation.

Structs

RuntimeEnvironmentVariable
Docker environment variable generated from a workspace runtime config.
RuntimeToolVersion
One declarative runtime tool version selected for a workspace.

Enums

RuntimeSpecError
Errors returned while parsing workspace runtime setup.
RuntimeTool
Runtime tools that can be installed declaratively.

Constants

CODEX_WS_APT_PACKAGES_ENV
Environment variable used by the runtime entrypoint for apt packages.
CODEX_WS_BUN_VERSION_ENV
Environment variable used by the runtime entrypoint for Bun version selection.
CODEX_WS_CLANG_VERSION_ENV
Environment variable used by the runtime entrypoint for Clang version selection.
CODEX_WS_CPP_VERSION_ENV
Environment variable used by the runtime entrypoint for C++ compiler version selection.
CODEX_WS_C_VERSION_ENV
Environment variable used by the runtime entrypoint for C compiler version selection.
CODEX_WS_DENO_VERSION_ENV
Environment variable used by the runtime entrypoint for Deno version selection.
CODEX_WS_DOTNET_VERSION_ENV
Environment variable used by the runtime entrypoint for .NET version selection.
CODEX_WS_GO_VERSION_ENV
Environment variable used by the runtime entrypoint for Go version selection.
CODEX_WS_JAVA_VERSION_ENV
Environment variable used by the runtime entrypoint for Java version selection.
CODEX_WS_NODE_VERSION_ENV
Environment variable used by the runtime entrypoint for Node.js version selection.
CODEX_WS_PHP_VERSION_ENV
Environment variable used by the runtime entrypoint for PHP version selection.
CODEX_WS_PYTHON_VERSION_ENV
Environment variable used by the runtime entrypoint for Python version selection.
CODEX_WS_RUBY_VERSION_ENV
Environment variable used by the runtime entrypoint for Ruby version selection.
CODEX_WS_RUST_VERSION_ENV
Environment variable used by the runtime entrypoint for Rust version selection.
CODEX_WS_SETUP_COMMANDS_ENV
Environment variable used by the runtime entrypoint for setup commands.
CODEX_WS_ZIG_VERSION_ENV
Environment variable used by the runtime entrypoint for Zig version selection.

Functions

validate_apt_packages
Validate apt package names from a workspace manifest.
validate_runtime_tool_versions
Validate a set of requested runtime tool versions.
validate_setup_commands
Validate setup commands from a workspace manifest.
validate_tool_version
Validate a runtime tool version from a workspace manifest.