pub enum RuntimeSpecError {
EmptyAptPackage,
InvalidAptPackage {
package: String,
},
EmptySetupCommand,
EmptyToolVersion {
tool: RuntimeTool,
},
InvalidToolVersion {
tool: RuntimeTool,
version: String,
},
ConflictingCompilerVersions {
first: String,
second: String,
},
}Expand description
Errors returned while parsing workspace runtime setup.
Variants
EmptyAptPackage
An apt package entry was empty or only whitespace.
InvalidAptPackage
An apt package entry contained characters that are unsafe for shell word splitting.
EmptySetupCommand
A setup command was empty or only whitespace.
EmptyToolVersion
A declarative runtime tool version was empty or only whitespace.
Fields

tool: RuntimeToolTool with an empty version.
InvalidToolVersion
A declarative runtime tool version contained unsafe characters.
ConflictingCompilerVersions
Multiple C/C++ compiler aliases requested different Clang versions.