parse_runtime_specs

Function parse_runtime_specs 

pub fn parse_runtime_specs(
    specs: &[String],
) -> Result<Vec<RuntimeLanguageVersion>, RuntimeSpecError>
Validate a list of runtime language specs.

Arguments

  • specs - Runtime specs in language:version form.

Returns

Runtime language versions in the same order as the input.

Errors

Returns RuntimeSpecError when any spec is invalid or configures a language twice.