pub struct RuntimeLanguageVersion { /* private fields */ }Expand description
One supported language runtime selected for a workspace.
Implementations
Sourceimpl RuntimeLanguageVersion
impl RuntimeLanguageVersion
Sourcepub fn parse(spec: &str) -> Result<Self, RuntimeSpecError>
pub fn parse(spec: &str) -> Result<Self, RuntimeSpecError>
Parse a runtime language specification.
Arguments
spec- Runtime spec inlanguage:versionform.
Returns
A validated runtime language version.
Errors
Returns RuntimeSpecError when the spec format, language, or version is unsupported.
Sourcepub const fn language(&self) -> RuntimeLanguage
pub const fn language(&self) -> RuntimeLanguage
Sourcepub fn version(&self) -> &str
pub fn version(&self) -> &str
Return the selected runtime version.
Returns
The exact version string supported by Codex Universal.
Sourcepub fn environment_variable(&self) -> RuntimeEnvironmentVariable
pub fn environment_variable(&self) -> RuntimeEnvironmentVariable
Convert this runtime spec into a Docker environment variable.
Returns
The CODEX_ENV_* variable consumed by Codex Universal.