pub struct RuntimeToolVersion { /* private fields */ }Expand description
One declarative runtime tool version selected for a workspace.
Implementations
Sourceimpl RuntimeToolVersion
impl RuntimeToolVersion
Sourcepub fn new(tool: RuntimeTool, version: String) -> Self
pub fn new(tool: RuntimeTool, version: String) -> Self
Sourcepub const fn tool(&self) -> RuntimeTool
pub const fn tool(&self) -> RuntimeTool
Sourcepub fn environment_variable(&self) -> RuntimeEnvironmentVariable
pub fn environment_variable(&self) -> RuntimeEnvironmentVariable
Convert this runtime tool into a Docker environment variable.
Returns
Runtime entrypoint environment variable.