Module workspace

Module workspace 

Saved workspace manifest management.

Structs

WorkspaceEntry
Saved workspace manifest entry.

Functions

add_workspace
Create a saved workspace manifest if needed and open it in an editor.
expand_home_path
Expand a leading ~ in a path.
list_workspaces
List saved workspace manifests.
resolve_workspace_path
Resolve a run --workspace value to a manifest path.
workspace_config_dir
Return the saved workspace manifest directory.
workspace_manifest_path
Return the manifest path for a saved workspace name.