run_workspace

Function run_workspace 

pub fn run_workspace(config: &RunConfig) -> Result<ExitCode>
Execute the configured workspace launch.

Arguments

  • config - Run configuration derived from CLI arguments.

Returns

The process exit code that should be returned by the CLI.

Errors

Returns an error when provider loading, manifest loading, folder validation, session directory creation, Docker command construction, or Docker execution fails.