Function load_default_user_config
Source pub fn load_default_user_config() -> Result<UserConfig, ConfigError>
Load user configuration from the default codex-ws config file.
Returns
Parsed user configuration, or an empty configuration when the file does not exist.
Errors
Returns an error when the config path cannot be resolved, the file cannot be read, or its JSON
is invalid.