Module docker

Module docker 

Docker sandbox command construction.

Structs

DockerLaunchConfig
Runtime paths and image settings used to construct a Docker sandbox command.
ProviderConfigFiles
Provider configuration files written on the host before launching Docker.

Enums

DockerError
Errors returned while constructing Docker launch commands.

Constants

DEFAULT_CODEX_IMAGE
Default Codex CLI Docker image used for sandbox launches.
DEFAULT_CODEX_IMAGE_VERSION
Version label expected on the locally built Codex workspace image.

Functions

build_docker_run_command
Build a Docker command for launching a Codex workspace sandbox.