Workspace runtime setup validation.
Structs
- Runtime
Environment Variable - Docker environment variable generated from a workspace runtime config.
- Runtime
Tool Version - One declarative runtime tool version selected for a workspace.
Enums
- Runtime
Spec Error - Errors returned while parsing workspace runtime setup.
- Runtime
Tool - Runtime tools that can be installed declaratively.
Constants
- CODEX_
WS_ APT_ PACKAGES_ ENV - Environment variable used by the runtime entrypoint for apt packages.
- CODEX_
WS_ BUN_ VERSION_ ENV - Environment variable used by the runtime entrypoint for Bun version selection.
- CODEX_
WS_ CLANG_ VERSION_ ENV - Environment variable used by the runtime entrypoint for Clang version selection.
- CODEX_
WS_ CPP_ VERSION_ ENV - Environment variable used by the runtime entrypoint for C++ compiler version selection.
- CODEX_
WS_ C_ VERSION_ ENV - Environment variable used by the runtime entrypoint for C compiler version selection.
- CODEX_
WS_ DENO_ VERSION_ ENV - Environment variable used by the runtime entrypoint for Deno version selection.
- CODEX_
WS_ DOTNET_ VERSION_ ENV - Environment variable used by the runtime entrypoint for .NET version selection.
- CODEX_
WS_ GO_ VERSION_ ENV - Environment variable used by the runtime entrypoint for Go version selection.
- CODEX_
WS_ JAVA_ VERSION_ ENV - Environment variable used by the runtime entrypoint for Java version selection.
- CODEX_
WS_ NODE_ VERSION_ ENV - Environment variable used by the runtime entrypoint for Node.js version selection.
- CODEX_
WS_ PHP_ VERSION_ ENV - Environment variable used by the runtime entrypoint for PHP version selection.
- CODEX_
WS_ PYTHON_ VERSION_ ENV - Environment variable used by the runtime entrypoint for Python version selection.
- CODEX_
WS_ RUBY_ VERSION_ ENV - Environment variable used by the runtime entrypoint for Ruby version selection.
- CODEX_
WS_ RUST_ VERSION_ ENV - Environment variable used by the runtime entrypoint for Rust version selection.
- CODEX_
WS_ SETUP_ COMMANDS_ ENV - Environment variable used by the runtime entrypoint for setup commands.
- CODEX_
WS_ ZIG_ VERSION_ ENV - Environment variable used by the runtime entrypoint for Zig version selection.
Functions
- validate_
apt_ packages - Validate apt package names from a workspace manifest.
- validate_
runtime_ tool_ versions - Validate a set of requested runtime tool versions.
- validate_
setup_ commands - Validate setup commands from a workspace manifest.
- validate_
tool_ version - Validate a runtime tool version from a workspace manifest.