Module runtime

Module runtime 

Workspace runtime setup validation.

Structs

RuntimeEnvironmentVariable
Docker environment variable generated from a workspace runtime config.

Enums

RuntimeSpecError
Errors returned while parsing workspace runtime setup.

Constants

CODEX_WS_APT_PACKAGES_ENV
Environment variable used by the runtime entrypoint for apt packages.
CODEX_WS_SETUP_COMMANDS_ENV
Environment variable used by the runtime entrypoint for setup commands.

Functions

validate_apt_packages
Validate apt package names from a workspace manifest.
validate_setup_commands
Validate setup commands from a workspace manifest.