Workspace runtime setup validation.
Structs
- Runtime
Environment Variable - Docker environment variable generated from a workspace runtime config.
Enums
- Runtime
Spec Error - Errors returned while parsing workspace runtime setup.
Constants
- CODEX_
WS_ APT_ PACKAGES_ ENV - Environment variable used by the runtime entrypoint for apt packages.
- CODEX_
WS_ SETUP_ COMMANDS_ ENV - Environment variable used by the runtime entrypoint for setup commands.
Functions
- validate_
apt_ packages - Validate apt package names from a workspace manifest.
- validate_
setup_ commands - Validate setup commands from a workspace manifest.