pub enum RuntimeLanguage {
Python,
Node,
Rust,
Go,
Swift,
Ruby,
Php,
Java,
}Expand description
Supported Codex Universal runtime languages.
Variants
Python
Python via CODEX_ENV_PYTHON_VERSION.
Node
Node.js via CODEX_ENV_NODE_VERSION.
Rust
Rust via CODEX_ENV_RUST_VERSION.
Go
Go via CODEX_ENV_GO_VERSION.
Swift
Swift via CODEX_ENV_SWIFT_VERSION.
Ruby
Ruby via CODEX_ENV_RUBY_VERSION.
Php
PHP via CODEX_ENV_PHP_VERSION.
Java
Java via CODEX_ENV_JAVA_VERSION.
Implementations
Sourceimpl RuntimeLanguage
impl RuntimeLanguage
Sourcepub fn parse(language: &str) -> Result<Self, RuntimeSpecError>
pub fn parse(language: &str) -> Result<Self, RuntimeSpecError>
Parse a supported runtime language or alias.
Arguments
language- Language name from a workspace runtime spec.
Returns
A supported runtime language.
Errors
Returns RuntimeSpecError::UnsupportedLanguage when the language is unknown.
Sourcepub const fn environment_variable(self) -> &'static str
pub const fn environment_variable(self) -> &'static str
Return the Codex Universal environment variable for this language.
Returns
The CODEX_ENV_* variable name.
Sourcepub const fn supported_versions(self) -> &'static [&'static str]
pub const fn supported_versions(self) -> &'static [&'static str]
Return supported versions for this language.
Returns
Versions supported by the current Codex Universal support matrix.