RuntimeSpecError

Enum RuntimeSpecError 

pub enum RuntimeSpecError {
    EmptyAptPackage,
    InvalidAptPackage {
        package: String,
    },
    EmptySetupCommand,
    EmptyToolVersion {
        tool: RuntimeTool,
    },
    InvalidToolVersion {
        tool: RuntimeTool,
        version: String,
    },
    ConflictingCompilerVersions {
        first: String,
        second: String,
    },
}
Errors returned while parsing workspace runtime setup.

Variants



EmptyAptPackage

An apt package entry was empty or only whitespace.



InvalidAptPackage

An apt package entry contained characters that are unsafe for shell word splitting.

Fields

package: String

Invalid package entry.



EmptySetupCommand

A setup command was empty or only whitespace.



EmptyToolVersion

A declarative runtime tool version was empty or only whitespace.

Fields

tool: RuntimeTool

Tool with an empty version.



InvalidToolVersion

A declarative runtime tool version contained unsafe characters.

Fields

tool: RuntimeTool

Tool with an invalid version.

version: String

Invalid version text.



ConflictingCompilerVersions

Multiple C/C++ compiler aliases requested different Clang versions.

Fields

first: String

First configured compiler version.

second: String

Conflicting compiler version.