Saved workspace manifest management.
Structs
- Workspace
Entry - Saved workspace manifest entry.
Functions
- add_
workspace - Create a saved workspace manifest if needed and open it in an editor.
- expand_
home_ path - Expand a leading
~in a path. - list_
workspaces - List saved workspace manifests.
- resolve_
workspace_ path - Resolve a
run --workspacevalue to a manifest path. - workspace_
config_ dir - Return the saved workspace manifest directory.
- workspace_
manifest_ path - Return the manifest path for a saved workspace name.