add_workspace

Function add_workspace 

pub fn add_workspace(
    sessions_root: &Path,
    workspace_name: &str,
) -> Result<PathBuf>
Create a saved workspace manifest if needed and open it in an editor.

Arguments

  • sessions_root - codex-ws state root.
  • workspace_name - Workspace name used for the manifest file.

Returns

Path to the saved workspace manifest.

Errors

Returns an error when the file cannot be created or the editor exits unsuccessfully.